============
Installation
============

Install scopus from PyPI:

.. code-block:: console

    $ pip install scopusreport

or directly from the GitHub repository (may be unstable):

.. code-block:: console

    $ pip install git+https://github.com/scopus-api/scopusreport

To generate reports using the Scopus database, set up `scopus` first: https://scopus.readthedocs.io/en/latest/configuration.html.

See extended description and examples in the :doc:`Examples </examples>` section.
